#!/usr/bin/env python

"""
Command option processing and other utilities for compiling and testing
programs.

Copyright (C) 2009 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from os.path import exists, join
import micropython

def parse_optimisations(args):

    "Parse 'args' for optimisation flags."

    if "-omax" in args:
        requested_optimisations = micropython.Program.supported_optimisations
    else:
        requested_optimisations = []
        for arg in args:
            if arg.startswith("-o"):
                for arg_part in arg[2:].split(","):
                    requested_optimisations.append(arg_part)

    return requested_optimisations

def show_optimisations():

    "Show available optimisation flags."

    return ",".join(micropython.Program.supported_optimisations)

def program(path, requested_optimisations, verbose=0):

    """
    Return a program object for the given module search 'path' and
    'requested_optimisations'.
    """

    i = micropython.Importer(path, verbose, requested_optimisations)
    p = micropython.Program(i, requested_optimisations)

    for d in path:
        builtins = join(d, "builtins.py")
        if exists(builtins):
            i.load_from_file(builtins, "__builtins__")
            break
    return p

# Convenience functions.

def get_program(path, args):

    """
    Return the program object for the given module search 'path' and command
    'args'.
    """

    requested_optimisations = parse_optimisations(args)
    return program(path, requested_optimisations, "-v" in args)

# vim: tabstop=4 expandtab shiftwidth=4
